@@ -259,7 +259,7 @@ while loop == 1: # This creates an infinite loop
       break
 print '==================='
 print docker_ip
-data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':pem_file_path,'noretry':'1'}]]}
+data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':home+'/FullAutoAPI/'+args.pem_file,'noretry':'1'}]]}
 time.sleep( 1 )
 docker_server1='';
 print "\nGoing to Attempt to Connect to new Docker Server via ssh . . .\n"
@@ -291,7 +291,7 @@ headerz, content = http.request(url, "POST", body=dumps(data), headers=headers)
 result = json.loads(content)
 result = json.loads(result['result'])
 print result
-data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':pem_file_path,'noretry':'1'}]]}
+data = {'cmd': [['connect_secure',{'ip':docker_ip,'login':'ec2-user','identityfile':home+'/FullAutoAPI/'+args.pem_file,'noretry':'1'}]]}
 time.sleep( 1 )
 docker_server1='';
 while loop == 1: # This creates an infinite loop
